# naivenlp
A naive toolkit for NLP.

## Tokenizers

`naivenlp` defines a interface for tokenization, you can implement your own tokeinizers easily.

By default, `naivenlp` provides `JiebaTokenizer`, which is refactoring from [jieba](https://github.com/fxsjy/jieba).


